# WebifyTk 🎨

Uma biblioteca incrível para criar interfaces gráficas modernas que parecem sites! 

## 🚀 COMO USAR:

### 1. INSTALAÇÃO
\\\ash
pip install webifytk
\\\

### 2. APP BÁSICO (RÁPIDO)
\\\python
from webifytk import WebifyApp

app = WebifyApp('Meu App', theme='dark')
app.add_navbar('TÍTULO INCRÍVEL 🔥', ['Home', 'Sobre'])
app.run()
\\\

### 3. APP COMPLETO (AVANÇADO)
\\\python
from webifytk import WebifyApp

# Cria a aplicação
app = WebifyApp('Meu App Incrível', theme='dark', engine='qt')  # engine='tkinter' também funciona

# Adiciona uma navbar moderna
app.add_navbar('MEU APP 🚀', [
    'Home', 
    'Produtos', 
    'Sobre', 
    'Contato'
])

# Hero section impressionante
app.add_hero(
    'TÍTULO PRINCIPAL AQUI!',
    'Um subtítulo interessante para complementar'
)

# Cards modernos
cards = [
    {
        'title': '🎮 Games',
        'content': 'Descrição incrível do card',
        'image': 'https://picsum.photos/300/200?1'
    },
    {
        'title': '🎨 Design',
        'content': 'Mais uma descrição incrível',
        'image': 'https://picsum.photos/300/200?2'
    },
    {
        'title': '🚀 Inovação',
        'content': 'Este card é impressionante',
        'image': 'https://picsum.photos/300/200?3'
    }
]
app.add_cards_section(cards)

# Se for Qt, adiciona uma webview
if app.engine == 'qt':
    app.add_web_view('https://google.com')

# Inicia a aplicação!
app.run()
\\\

### 4. TEMAS DISPONÍVEIS
\\\python
# Tema escuro moderno
app = WebifyApp(theme='dark')

# Tema claro elegante
app = WebifyApp(theme='light')
\\\

### 5. COMPONENTES DISPONÍVEIS

#### Navbar (Menu superior)
\\\python
app.add_navbar(
    'TÍTULO', 
    ['Menu 1', 'Menu 2', 'Menu 3']
)
\\\

#### Hero (Seção principal)
\\\python
app.add_hero(
    'TÍTULO PRINCIPAL',
    'Subtítulo interessante'
)
\\\

#### Cards (Elementos visuais)
\\\python
cards = [
    {
        'title': 'TÍTULO',
        'content': 'DESCRIÇÃO',
        'image': 'URL_DA_IMAGEM'  # opcional
    }
]
app.add_cards_section(cards)
\\\

#### WebView (Exclusivo Qt)
\\\python
app.add_web_view('https://google.com')
\\\

### 6. PERSONALIZAÇÃO AVANÇADA

#### Cores
\\\python
from webifytk import WebifyStyle

WebifyStyle.COLORS = {
    'primary': '#ff0000',  # Vermelho vibrante
    'secondary': '#00ff00',  # Verde moderno
    'success': '#0000ff',  # Azul elegante
}
\\\

#### Fontes
\\\python
WebifyStyle.FONTS = {
    'heading': ('Arial', 30, 'bold'),  # Título principal
    'body': ('Arial', 14),  # Texto normal
}
\\\

### 7. RESOLUÇÃO DE PROBLEMAS

Se houver erro de versão:
\\\ash
python upgrade_python.py
\\\

Se faltar Qt:
\\\ash
pip install PyQt6 PyQt5 PyQtWebEngine
\\\

### 8. DICAS IMPORTANTES

1. Use imagens quadradas nos cards
2. Adicione emojis nos títulos 🔥
3. Qt oferece melhor performance que Tkinter
4. Não esqueça de dar uma estrela no projeto ⭐

### 9. EXEMPLOS PRÁTICOS

#### App de Portfólio
\\\python
app = WebifyApp('Meu Portfólio', theme='dark')

app.add_navbar('MEU NOME 🚀', ['Projetos', 'Skills', 'Contato'])

app.add_hero(
    'Desenvolvedor Criativo',
    'Criando aplicações incríveis'
)

projetos = [
    {
        'title': '🎮 Projeto 1',
        'content': 'Um projeto incrível',
        'image': 'url_do_projeto'
    },
    {
        'title': '🤖 Projeto 2',
        'content': 'Outro projeto incrível',
        'image': 'url_do_projeto2'
    }
]
app.add_cards_section(projetos)

app.run()
\\\

#### App de Loja
\\\python
app = WebifyApp('Minha Loja', theme='dark', engine='qt')

app.add_navbar('LOJA INCRÍVEL 🛒', ['Produtos', 'Carrinho', 'Login'])

app.add_hero(
    'SUPER PROMOÇÃO 🔥',
    'Descontos imperdíveis!'
)

produtos = [
    {
        'title': '👕 Camiseta',
        'content': 'R$ 49,90',
        'image': 'url_camiseta'
    },
    {
        'title': '👖 Calça',
        'content': 'R$ 99,90',
        'image': 'url_calca'
    }
]
app.add_cards_section(produtos)

app.run()
\\\

## 🎮 COMECE A CRIAR!

Agora é sua vez de criar aplicações incríveis! 

Se precisar de ajuda:
1. Revise esta documentação
2. Teste os exemplos
3. Personalize ao seu estilo
4. Sucesso! 🚀

## ⭐ Deixe sua estrela se gostou!
